import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'finbox_bureau_plugin_platform_interface.dart';

/// An implementation of [FinBoxBureauPluginPlatform] that uses method channels.
class MethodChannelFinBoxBureauPlugin extends FinBoxBureauPluginPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('finbox_bureau_plugin');

  @override
  Future<String?> getPlatformVersion() async {
    final version = await methodChannel.invokeMethod<String>('getPlatformVersion');
    return version;
  }

  @override
  MethodChannel getMethodChannel() {
    return methodChannel;
  }

  @override
  void initSdk(String env, String apiKey, String customerId, String firstName,
      String? middleName, String? lastName, String phone) async {
    try {
      await methodChannel.invokeMethod('initSdk', <String, dynamic>{
        'apiKey': apiKey,
        'env': env,
        'customerId': customerId,
        'firstName': firstName,
        'middleName': middleName,
        'lastName': lastName,
        'phone': phone
      });
    } on PlatformException catch (e) {
      print("Error on initializing bureau connect ${e.message}");
    }
  }

  @override
  void startBureauJourney() async {
    try {
      await methodChannel.invokeMethod('startBureauJourney');
    } on PlatformException catch (e) {
      print("Error on launching bureau connect ${e.message}");
    }
  }
}
