import 'package:plugin_platform_interface/plugin_platform_interface.dart';
import 'package:flutter/services.dart';

import 'finbox_bureau_plugin_method_channel.dart';

abstract class FinBoxBureauPluginPlatform extends PlatformInterface {
  /// Constructs a FinBoxBureauPluginPlatform.
  FinBoxBureauPluginPlatform() : super(token: _token);

  static final Object _token = Object();

  static FinBoxBureauPluginPlatform _instance = MethodChannelFinBoxBureauPlugin();

  /// The default instance of [FinBoxBureauPluginPlatform] to use.
  ///
  /// Defaults to [MethodChannelFinBoxBureauPlugin].
  static FinBoxBureauPluginPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [FinBoxBureauPluginPlatform] when
  /// they register themselves.
  static set instance(FinBoxBureauPluginPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  MethodChannel getMethodChannel() {
    throw UnimplementedError('getMethodChannel() has not been implemented.');
  }

  Future<String?> getPlatformVersion() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  void initSdk(String env, String apiKey, String customerId, String firstName,
      String? middleName, String? lastName, String phone) {
    throw UnimplementedError('initSdk() has not been implemented.');
  }

  void startBureauJourney() {
    throw UnimplementedError('startBureauJourney() has not been implemented.');
  }
}
